@@ -42,11 +42,13 @@ class counted_lock
 template <class dataObject, class syncObject>
 class thread_safe 
 {
+ private:
+	thread_safe();
 	dataObject data;
 	syncObject sync;
 
  public:
-	thread_safe(const dataObject& _data) : data(_data) {}
+	thread_safe(const dataObject& _data) : data(_data), sync() {}
 	inline void operator=(const dataObject& _data) 
 	{
 		lock<syncObject> L(sync);
