@@ -17,6 +17,7 @@
 #include "platform.h"
 #include "glcontext.h"
 #include <GL/gl.h>
+#include <GL/glu.h>
 
 namespace visual
 {
@@ -82,8 +83,6 @@ struct wglContext : glContext
 
     glFont* getFont( const char* description, double size);
 
-	void add_pending_glDeleteList(int base, int howmany);
-
   private:
     std::map< std::pair< std::string, double>, wglFont* > fontCache;
     friend struct wglWindowClass;
@@ -105,13 +104,7 @@ struct wglContext : glContext
     LRESULT winMessage( HWND, UINT, WPARAM, LPARAM );
     void error( std::string where);
 
-    friend struct wglFont;
-    
-    // This is a list of glDeleteLists calls that should be made the next time
-    // the context is made active.
-    mutex list_lock;
-	std::vector<std::pair<int, int> > pending_glDeleteLists;
-    
+    friend struct wglFont;    
 };
 
 } // !namespace visual
