@@ -86,8 +86,6 @@ struct xglContext : glContext
 	inline std::string lastError() { return error_message; }
     
 	glFont* getFont(const char* description, double size);
-	
-	void add_pending_glDeleteList(int base, int howmany);
 
  private:
 	GtkWidget* window;
@@ -100,11 +98,6 @@ struct xglContext : glContext
 	vector mousePos, oldMousePos;
 	bool mouseLocked;
 	std::queue<std::string> keys;
-	
-	// A list of all the glDeleteLists calls that should be made when this
-	// context is next made active.
-	mutex list_lock;
-	std::vector<std::pair<int, int> > pending_glDeleteLists;
 
 	// Event callback handlers.
 	static void realize_cb( GtkWidget* widget, gpointer data);
