@@ -249,6 +249,8 @@ class slider(ctrl):
             width = args['width']
         if args.has_key('min'):
             self.min = args['min']
+            if self.__value == 0:
+                self.__value = self.min
         if args.has_key('max'):
             self.max = args['max']
         if args.has_key('color'):
@@ -258,7 +260,7 @@ class slider(ctrl):
                        pos=self.pos+self.axis*self.length/2., axis=self.axis,
                        size=(self.length,0.5*width,0.5*width), color=shaftcolor)
         self.indicator = box(display=disp,
-                       pos=self.pos+self.axis*self.__value*self.length/(self.max-self.min),
+                       pos=self.pos+self.axis*(self.__value-self.min)*self.length/(self.max-self.min),
                        axis=self.axis,
                        size=(width,width,width), color=scolor)
         self.active = self.indicator
@@ -267,19 +269,19 @@ class slider(ctrl):
         return self.__value
 
     def setvalue(self, val):
-        self.update(self.pos+self.axis*val*self.length/(self.max-self.min))
+        self.update(self.pos+self.axis*(val-self.min)*self.length/(self.max-self.min))
         self.__value = val
 
     value = property(getvalue, setvalue) # establishes special getattr/setattr handling
 
     def update(self, pos):
-        val = dot((pos-self.pos),self.axis)*(self.max-self.min)/self.length
+        val = self.min+dot((pos-self.pos),self.axis)*(self.max-self.min)/self.length
         if val < self.min:
             val = self.min
         elif val > self.max:
             val = self.max
         if val != self.__value:
-            self.indicator.pos = self.pos+self.axis*val*self.length/(self.max-self.min)
+            self.indicator.pos = self.pos+self.axis*(val-self.min)*self.length/(self.max-self.min)
             self.__value = val
             self.execute()
 
