@@ -98,9 +98,7 @@ class gdisplay:
                  foreground=None, background=None):
         global lastgdisplay
         lastgdisplay = self
-        test = sphere(visible=0)
-        currentdisplay = test.display
-        test = None # discard test sphere
+        currentdisplay = display.get_selected()
         if title is None:
             title = 'Graph'
         self.width = width
@@ -579,6 +577,8 @@ class ghistogram:
         else:
             self.delta = delta
         self.vbars = []
+        self.gdisplay.resize(bins[0],1.0)
+        self.gdisplay.resize(bins[-1],1.0)
 
     def plot(self, data=None, accumulate=None, average=None, color=None):
         if color is None:
@@ -587,6 +587,7 @@ class ghistogram:
             self.accumulate = accumulate
         if average is not None:
             self.average = average
+        if data is None: return
         n = searchsorted(sort(data), self.bins)
         n = concatenate([n, [len(data)]])
         histo = n[1:]-n[:-1]
@@ -599,7 +600,7 @@ class ghistogram:
         if ymax == 0.: ymax == 1.
         self.gdisplay.resize(self.bins[-1],ymax)
         for nbin in range(len(self.bins)):
-            x = (nbin+0.5)*self.delta
+            x = self.bins[0]+(nbin+0.5)*self.delta
             y = self.histaccum[nbin]
             if self.nhist == 1.:
                 self.vbars.append(box(display=self.gdisplay.display, pos=(x,y/2.,-dz),
