@@ -316,7 +316,7 @@ class faces( cvisual.faces):
 class helix(object):
 	def __init__( self, _other=None, visible=1,
                         pos=vector(), axis=vector(1,0,0), radius=0.2, 
-			coils=5, thickness=None, length=1.0, up=vector(0,1,0),
+			coils=5, thickness=None, length=None, up=vector(0,1,0),
                         x=None, y=None, z=None, color=color.white,
                         red=None, green=None, blue=None,
                         **keywords):
@@ -335,10 +335,12 @@ class helix(object):
                 if z is not None:
                     pos[2] = z
 		axis = vector(axis)
+                if length is None:
+                    length = axis.mag
+		self.cached_length = length
 		axis = length*axis.norm()
-                self.__frame = frame(display=disp, frame=fr, pos=pos, axis=axis.norm(), up=up)
-		self.cached_length = axis.mag
-		if thickness is None:
+                self.__frame = frame(display=disp, frame=fr, pos=pos, axis=axis, up=up)
+                if thickness is None:
 		    thickness = radius/20.
 		if red is not None:
                     color[0] = red
@@ -377,6 +379,7 @@ class helix(object):
 	def _set_length(self, length):
 		self.helix.x *= ( length/self.cached_length)
 		self.cached_length = length
+		self.__frame.axis = length*self.__frame.axis.norm()
 	def _get_length(self):
 		return self.cached_length
 
