@@ -9,6 +9,9 @@
 #include <cassert>
 #include <iostream>
 
+
+#include <fstream> // debugging
+
 #include <boost/python/class.hpp>
 #include <boost/python/object.hpp>
 #include <boost/python/object_operators.hpp>
@@ -490,7 +493,10 @@ curve::thickline( rView& view)
 	const int curve_around = 4;
 	static vertex projected[MAX_SEGMENTS * curve_around];
 	static float light[MAX_SEGMENTS * curve_around * 3];
-	int step = (count + MAX_SEGMENTS-1) / MAX_SEGMENTS;
+
+	float fstep = ( ((float) count)-1.0)/(MAX_SEGMENTS-1.0);
+	if (fstep < 1.0) fstep = 1.0;
+	size_t iptr=0, iptr3, pcount=0;
 
 	vertex *pr = projected;
 	float *lt = light;
@@ -500,15 +506,15 @@ curve::thickline( rView& view)
 
 	vector x, y, lastx, lasty;
 
-	int npoints = 0;
-	
 	// pos and color iterators
-	const double* v_i = (double*)( data(pos));
+	const double* p_i = (double*)( data(pos));
 	const double* c_i = (double*)( data(color));
+	vector prev = vector( p_i[0], p_i[1], p_i[2]);
 
-	for(size_t corner=0; corner < count/step; ++corner, v_i += step*3, c_i += step*3) {
-		// The vector to which v_i currently points towards.
-		vector current = vector( v_i[0], v_i[1], v_i[2]);
+	for (float fptr=0.0; iptr < count; fptr += fstep, iptr = (int) (fptr+.5), ++pcount) {
+		iptr3 = 3*iptr;
+		// keep track of min/max extent of scene
+		vector current = vector( p_i[iptr3], p_i[iptr3+1], p_i[iptr3+2]);
 		view.ext_point( current);
 
 		/* To construct the circle of vertices around a point on the curve,
@@ -518,23 +524,12 @@ curve::thickline( rView& view)
 		 * this point.  The cross product and the difference of these vectors
 		 * are orthogonal and lie in the appropriate plane.
 		 */
-
-		if (corner && (corner+1 < count/step)) {
-			// Any point except the first and last.
-			vector next( v_i[3], v_i[4], v_i[5]); // The next vector in pos
-			vector prev( v_i[-3], v_i[-2], v_i[-1]); // The previous vector in pos
-			vector A = next - current;
-			vector B = current - prev;
-			x = (A.norm()-B.norm()).norm();
-			y = A.cross(B).norm();
-			if (!x || !y) {
-				x = lastx;
-				y = lasty;
-			}
-		}
-		else if (corner) {
+		
+		// Look ahead to find out what the next point is.
+		size_t nextiptr = (int) (fptr+fstep+.5);
+		
+		if (nextiptr >= count) {
 			// The last point
-			vector prev( v_i[-3], v_i[-2], v_i[-1]);
 			vector A = current - prev;
 			A = A.norm();
 			x = A.cross( vector(0,0,1));
@@ -544,16 +539,30 @@ curve::thickline( rView& view)
 			y = A.cross(x);
 		}
 		else {
-			// The first point
-			vector next( v_i[3], v_i[4], v_i[5]);
-			vector A = next - current;
-			A = A.norm();
-			x = A.cross( vector(0,0,1));
-			if (!x)
-				x = A.cross( vector(1,0,0));
-			x = x.norm();
-			y = A.cross(x);
+			vector next = vector( p_i[3*nextiptr], p_i[3*nextiptr+1], p_i[3*nextiptr+2]);
+			if (iptr) {
+				// Any point except the first and last.
+				vector A = next - current;
+				vector B = current - prev;
+				x = (A.norm()-B.norm()).norm();
+				y = A.cross(B).norm();
+				if (!x || !y) {
+					x = lastx;
+					y = lasty;
+				}
+			}
+			else {
+				// The first point
+				vector A = next - current;
+				A = A.norm();
+				x = A.cross( vector(0,0,1));
+				if (!x)
+					x = A.cross( vector(1,0,0));
+				x = x.norm();
+				y = A.cross(x);
+			}
 		}
+		prev = current; // save current point
 
 		// experimental: kink prevention
 		if (x.dot(lastx) < 0)
@@ -572,9 +581,9 @@ curve::thickline( rView& view)
 		y = y * radius;
 		
 		// Manipulate colors when we are in stereo mode.
-		rgb rendered_color( static_cast<float>(c_i[0]), 
-		                    static_cast<float>(c_i[1]),
-		                    static_cast<float>(c_i[2]));
+		rgb rendered_color( static_cast<float>(c_i[iptr3]), 
+		                    static_cast<float>(c_i[iptr3+1]),
+		                    static_cast<float>(c_i[iptr3+2]));
 		if (view.anaglyph) {
 			if (view.coloranaglyph) {
 				rendered_color = rendered_color.unsaturate();
@@ -586,7 +595,6 @@ curve::thickline( rView& view)
 			}
 		}
 		
-		npoints++;
 		for (int a=0; a < curve_around; a++) {
 			float c = cost[a];
 			float s = sint[a];
@@ -616,12 +624,12 @@ curve::thickline( rView& view)
 			ai = 0;
 		}
 
-		for(int i=0; i<npoints; i+=127) {
+		for(int i=0; i<pcount; i+=127) {
 			glVertexPointer(4, GL_DOUBLE, sizeof(vertex), &projected[i*curve_around + ai].x);
 			glColorPointer(3, GL_FLOAT, sizeof(float)*3, &light[(i*curve_around + ai)*3] );
 
-			if (npoints-i < 128)
-				glDrawElements(GL_TRIANGLE_STRIP, 2*(npoints-i), GL_UNSIGNED_INT, ind);
+			if (pcount-i < 128)
+				glDrawElements(GL_TRIANGLE_STRIP, 2*(pcount-i), GL_UNSIGNED_INT, ind);
 			else
 				glDrawElements(GL_TRIANGLE_STRIP, 256, GL_UNSIGNED_INT, ind);
 		}
@@ -633,21 +641,25 @@ curve::thinline( rView& view )
 {
 	// The maximum number of line segments to draw.
 	const int LINE_LENGTH = 1024;
-	// Data storage for the color data.
+	// Data storage for the color and position data.
 	static float color_data[LINE_LENGTH][3];
-
-	// The number of steps to take for each stride.
-	// This evaluates to 1 when count < LINE_LENGTH, and something larger else.
-	int step = (count + LINE_LENGTH - 1) / LINE_LENGTH;
+	static float pos_data[LINE_LENGTH][3];
+	float fstep = ( ((float) count)-1.0)/(LINE_LENGTH-1.0);
+	if (fstep < 1.0) fstep = 1.0;
+	size_t iptr=0, iptr3, pcount=0;
 
 	const double* p_i = (double*)( data(this->pos));
 	const double* c_i = (double*)( data(this->color));
-
-	for (size_t i = 0; i < count / step; ++i, p_i += step*3, c_i += step*3) {
-		view.ext_point( p_i);
+	
+	for (float fptr=0.0; iptr < count; fptr += fstep, iptr = (int) (fptr+.5), ++pcount) {
+		iptr3 = 3*iptr;
+		view.ext_point( p_i+iptr3); // keep track of min/max extent of scene
+		pos_data[pcount][0] = p_i[iptr3];
+		pos_data[pcount][1] = p_i[iptr3+1];
+		pos_data[pcount][2] = p_i[iptr3+2];
 		
 		if (view.anaglyph) {
-			rgb rendered_color( c_i[0], c_i[1], c_i[2]);
+			rgb rendered_color( c_i[iptr3], c_i[iptr3+1], c_i[iptr3+2]);
 			if (view.coloranaglyph) {
 				rendered_color = rendered_color.unsaturate();
 			}
@@ -656,25 +668,28 @@ curve::thinline( rView& view )
 				rendered_color.g = 
 				rendered_color.b = rendered_color.grayscale();
 			}
-			color_data[i][0] = rendered_color.r;
-			color_data[i][1] = rendered_color.g;
-			color_data[i][2] = rendered_color.b;
+			color_data[pcount][0] = rendered_color.r;
+			color_data[pcount][1] = rendered_color.g;
+			color_data[pcount][2] = rendered_color.b;
+		}
+		else {
+			color_data[pcount][0] = c_i[iptr3];
+			color_data[pcount][1] = c_i[iptr3+1];
+			color_data[pcount][2] = c_i[iptr3+2];
 		}
 	}
-	
+		
 	view.wct.gl_load();
 
 	glEnableClientState( GL_VERTEX_ARRAY);
 	glEnableClientState( GL_COLOR_ARRAY);
-	glVertexPointer( 3, GL_DOUBLE, 3*sizeof(double)*step, data(this->pos));
-	if (view.anaglyph)
-		glColorPointer( 3, GL_FLOAT, 3*sizeof(float), color_data);
-	else
-		glColorPointer( 3, GL_DOUBLE, 3*sizeof(double)*step, data(this->color));
+	glVertexPointer( 3, GL_FLOAT, 3*sizeof(float), pos_data);
+	glColorPointer( 3, GL_FLOAT, 3*sizeof(float), color_data);
 	glShadeModel( GL_SMOOTH);
 
-	glDrawArrays(GL_LINE_STRIP, 0, count/step);
+	glDrawArrays(GL_LINE_STRIP, 0, pcount);
 	glLoadIdentity();
+
 }
 
 void
