@@ -84,6 +84,11 @@ Display::Display(Device& dev)
 	: mouse(new mouseObject()),
 	kb(new kbObject()),
 	cursor(new cursorObject()),
+	c_title_changed(false),
+	c_uniform(true),
+	c_rotation_enabled(true),
+	c_zoom_enabled(true),
+	tanfov( std::tan( 60*pi/180)),
 	title("VPython"),
 	title_changed(false),
 	center(0,0,0),
