@@ -6,7 +6,9 @@
 #include "exceptions.h"
 #include "frame.h"
 #include <iostream>
+#include <sstream>
 #include <stdexcept>
+#include <GL/glu.h>
 
 /***************** GLDevice *******************/
 
@@ -924,8 +926,23 @@ GLDevice::draw( int eyeOffset, bool doPick, bool anaglyph, bool coloranaglyph)
 	glBlendFunc( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 	glDepthMask( GL_FALSE);
 	
-	for (size_t i=0; i < view.sortlists.size(); ++i)
+	// Clear the error state
+	glGetError();
+	for (size_t i=0; i < view.sortlists.size(); ++i) {
+		
 		glCallList( view.sortlists[i]);
+		// Check for errors
+		GLenum err_code = glGetError();
+		// Insert the manual cast from the unsigned char pointer to signed char
+		// pointer type.
+		if (err_code != GL_NO_ERROR) {
+			std::ostringstream err;
+			err << "***VPYTHON RENDERING ERROR*** ";
+			err << __FILE__ << ":" << __LINE__ << " " << (const char*)gluErrorString(err_code);
+			err << " when rendering OpenGL display list number " << view.sortlists[i];
+			std::cerr << err.str() << std::endl;
+		}
+	}
 	for (size_t i=0; i < view.sortlists.size(); ++i)
 		glDeleteLists( view.sortlists[i],1);
 	
