@@ -22,7 +22,10 @@ Label::Label()
 	font_height(0),
 	box_enabled(true),
 	line_enabled(true),
+#if !USE_NEWFONT
 	font(0),
+#endif
+	text_changed(true),
 	textWidth(0.0),
 	lineColor(1,1,1),
 	opacity(0.66)
@@ -40,7 +43,10 @@ Label::Label( const Label& other)
 	font_height( other.font_height),
 	box_enabled( other.box_enabled),
 	line_enabled( other.line_enabled),
+#if !USE_NEWFONT
 	font( 0),
+#endif
+	text_changed( true),
 	textWidth( other.textWidth),
 	lineColor( other.lineColor),
 	opacity( other.opacity),
@@ -50,8 +56,10 @@ Label::Label( const Label& other)
 
 Label::~Label() 
 {
+	#if !USE_NEWFONT
 	if (font) 
 		font->release();
+	#endif
 }
 
 std::string
@@ -59,12 +67,16 @@ Label::get_text()
 {
 	if (text[0] == std::string( ""))
 		return std::string( "");
+#if USE_NEWFONT
+	return text[0];
+#else
 	std::ostringstream ret;
 	ret << text[0];
 	for ( text_iterator i = text.begin()+1; i != text.end(); i++) {
 		ret << '\n' << *i;
 	}
 	return ret.str();
+#endif
 }
 
 void 
@@ -76,11 +88,21 @@ Label::refreshCache()
 void 
 Label::glRender( rView& view) 
 {
+#if USE_NEWFONT
+	if (!font) {
+		font = view.cx.getFont( font_height);
+		if (!font)
+			return;
+	}
+	if (text_changed || !lay_out)
+		lay_out = font->lay_out( text.begin()->c_str());
+#else
 	if (!font) {
 		font = view.cx.getFont(font_description.c_str(), font_height);
 		if (!font) 
 			return;
 	}
+#endif
 
 	glNewList( view.createSortList(), GL_COMPILE );
 	glDisable(GL_DEPTH_TEST);
@@ -101,7 +123,7 @@ Label::glRender( rView& view)
 	if (space) {
 		double cube[6][3] = { {1,0,0}, {-1,0,0}, {0,1,0},{0,-1,0}, {0,0,1},{0,0,-1} };
 		double r2 = 0;
-		for(int f=0;f<6;f++) {
+		for(int f = 0; f < 6; f++) {
 			vector v = vector(cube[f])*space + pos;
 			v = view.wct*v/view.wct.w(v) - proj_pos;
 			double m = (v.x*v.x / xpix/xpix) + (v.y*v.y / ypix/ypix);
@@ -110,13 +132,19 @@ Label::glRender( rView& view)
 		}
 
 		vector spacev = alignv.norm() * std::sqrt(r2);  // in pixels
-		start = start + vector( spacev.x * xpix, spacev.y * ypix);
+		start += vector( spacev.x * xpix, spacev.y * ypix);
 	}
 
 	vector end = start + alignv;
 
 	double borderx = border * 2 / view.cx.width();
 	double bordery = border * 2 / view.cx.height();
+	
+#if USE_NEWFONT
+	vector extent = lay_out->extent();
+	// TODO: Determine the value of origin
+	vector origin;
+#else
 	if (textWidth == 0.0) {
 		for (text_iterator i = text.begin(); i != text.end(); ++i) {
 			if (font->getWidth(i->c_str()) > textWidth) {
@@ -124,12 +152,15 @@ Label::glRender( rView& view)
 			}
 		}
 	}
-	
+
 	double width = borderx + textWidth;
 	double descent = font->descent() + bordery;
 	double ascent = font->ascent() + bordery;
-	double height = ascent + descent;         
+	double height = ascent + descent;
 
+	// Assign origin to be the center of the bounding box containing the text.
+	// It will be end + some vector, depending on whether the offset is greater
+	// along the x-axis or greater along the y-axis.
 	vector origin;
 	if ( !alignv ) {
 		// center align, center vertically
@@ -209,15 +240,19 @@ Label::glRender( rView& view)
 		glVertex3d( end.x, end.y, end.z);
 		glEnd();
 	}
+#endif
 
 	glColor3f( color.r, color.g, color.b);
+#if USE_NEWFONT
+	lay_out->gl_render();
+#else
 	for (size_t i = 0; i < text.size(); i++) {
 		glRasterPos3d( origin.x
 			, origin.y + ((text.size()-1)*height) - (i*height)
 			, origin.z );
 		font->draw(text[i].c_str());
 	}
-
+#endif
 	glEnable( GL_DEPTH_TEST);
 	glEndList();
 }
@@ -310,10 +345,14 @@ Label::set_height( const double& h)
 {
 	write_lock L( mtx);
 	font_height = h;
-	if (font) { 
-		font->release(); 
-		font = 0; 
+#if USE_NEWFONT
+	font.reset();
+#else
+	if (font) {
+		font->release();
+		font = 0;
 	}
+#endif
 }
 
 void
@@ -328,10 +367,14 @@ Label::set_font( const std::string& s)
 {
 	write_lock L( mtx);
 	font_description = s;
+#if USE_NEWFONT
+	font.reset();
+#else
 	if (font) {
 		font->release();
 		font = 0;
 	}
+#endif
 }
 
 void
@@ -359,6 +402,9 @@ void
 Label::set_text( const std::string& new_text)
 {
 	write_lock L( mtx);
+#if USE_NEWFONT
+	text.push_back( new_text);
+#else
 	textWidth = 0.0;
 
 	text.clear();
@@ -367,6 +413,8 @@ Label::set_text( const std::string& new_text)
 	while (std::getline( buf, line)) {;
 		text.push_back( line);
 	}
+#endif
+	text_changed = true;
 }
 
 void
