@@ -285,8 +285,13 @@ vector::orthogonal( const vector& v) const throw()
 double 
 vector::diff_angle( const vector& v) const throw()
 {
-	// By taking dot product of the normal vectors, we minimize the possible error.
-	return std::acos( this->norm().dot( v.norm()) );
+	double magfirst = this->mag2();
+	double magsecond = v.mag2();
+	if (magfirst == 0.0 || magsecond == 0.0)
+		return (double) 0.0;
+	else
+		// By taking dot product of the normal vectors, we minimize the possible error.
+		return std::acos( this->norm().dot( v.norm()) );
 }
   
 std::string 
