@@ -128,14 +128,6 @@ glFont* wglContext::getFont(const char* description, double size)
 
 /*************** wglWindowClass interface **************/
 
-void
-wglContext::add_pending_glDeleteList(int base, int howmany)
-{
-	Cache::write_lock L(list_lock);
-	pending_glDeleteLists.push_back( std::make_pair(base, howmany));	
-}
-
-
 struct wglWindowClass 
 {
 	wglWindowClass();
@@ -673,7 +665,12 @@ LRESULT wglContext::winMessage( HWND, UINT msg, WPARAM wParam, LPARAM lParam)
 			if (fCtrl) strcat(kStr,"ctrl+");
 			if (fAlt) strcat(kStr,"alt+");
 			if (fShift) strcat(kStr,"shift+");
-			strcat(kStr,kNameP);
+			strcat(kStr,kNameP);			
+			if (strcmp(kStr,"escape") == 0) {
+				cls.clearContext( hWnd );
+				hWnd = 0;
+				return 0;
+			}
 			keys.push_back( std::string(kStr));
 		}
 		break;
@@ -704,12 +701,6 @@ void wglContext::makeCurrent()
 		lasthdc = wglGetCurrentDC();
 		lastglrc = wglGetCurrentContext();
 		wglMakeCurrent( hdc, hglrc );
-		Cache::write_lock L( list_lock);
-		for (std::vector<std::pair<int, int> >::iterator i = pending_glDeleteLists.begin();
-			i != pending_glDeleteLists.end(); ++i) {
-			glDeleteLists(i->first, i->second);	
-		}
-		pending_glDeleteLists.clear();
 	}
 	current++;
 }
